@@ -3,11 +3,11 @@ Author: Anton Gladky <gladk@debian.org>
 Bug-Debian: https://bugs.debian.org/830342
 Last-Update: 2016-08-25
 
-Index: mayavi-4.4.3/tvtk/vtk_parser.py
+Index: mayavi2-4.5.0/tvtk/vtk_parser.py
 ===================================================================
---- mayavi-4.4.3.orig/tvtk/vtk_parser.py
-+++ mayavi-4.4.3/tvtk/vtk_parser.py
-@@ -301,11 +301,10 @@ class VTKMethodParser:
+--- mayavi2-4.5.0.orig/tvtk/vtk_parser.py
++++ mayavi2-4.5.0/tvtk/vtk_parser.py
+@@ -315,11 +315,10 @@ class VTKMethodParser:
  
          """
          # VTK 6.2 false built in funcs/methods are ignored
@@ -22,4 +22,4 @@ Index: mayavi-4.4.3/tvtk/vtk_parser.py
 +            return None
          # Remove all the C++ function signatures.
          doc = method.__doc__
-         doc = doc[:doc.find('\n\n')]
+         if doc is None:
